schemaVersion property
Envelope-shape version at the maintainer, for consumers that need to reason about wire-shape evolution.
Implementation
final int? schemaVersion;
Envelope-shape version at the maintainer, for consumers that need to reason about wire-shape evolution.
final int? schemaVersion;