session property
The session the consumer has just created or refreshed for this subject. Carries
sessionKey when the request bound one.
Implementation
final Session session;
The session the consumer has just created or refreshed for this subject. Carries
sessionKey when the request bound one.
final Session session;