refreshExpiresIn property
Seconds from issuance until the refresh token expires, when one was issued.
Implementation
final int? refreshExpiresIn;
Seconds from issuance until the refresh token expires, when one was issued.
final int? refreshExpiresIn;