rejected property
Keys that were not applied, each with a reason. Empty when every override succeeded.
Implementation
final List<RejectedKey> rejected;
Keys that were not applied, each with a reason. Empty when every override succeeded.
final List<RejectedKey> rejected;