pushCapable property
Whether the device now has a usable wake channel (true after a successful set, false after a clear).
Implementation
final bool pushCapable;
Whether the device now has a usable wake channel (true after a successful set, false after a clear).
final bool pushCapable;