disabledAt property
Present when the device has been disabled (device/disable). Disabled devices cannot authenticate but their record is retained for audit.
Implementation
final String? disabledAt;
Present when the device has been disabled (device/disable). Disabled devices cannot authenticate but their record is retained for audit.
final String? disabledAt;