lastInbound property
The last document the control plane received from this instance. Absent when it has received none.
Implementation
final TransportObservation? lastInbound;
The last document the control plane received from this instance. Absent when it has received none.
final TransportObservation? lastInbound;