lastOutbound property
The last document the control plane delivered to this instance. Absent when it has delivered none.
Implementation
final TransportObservation? lastOutbound;
The last document the control plane delivered to this instance. Absent when it has delivered none.
final TransportObservation? lastOutbound;