sync property
The repository's sync after the resolution. The resolved item is no longer
outstanding; the state is drift while other items remain, and otherwise pending
until the bridge confirms the forge matches.
Implementation
final Sync sync;
The repository's sync after the resolution. The resolved item is no longer
outstanding; the state is drift while other items remain, and otherwise pending
until the bridge confirms the forge matches.
final Sync sync;