mode property

PayloadMode mode
final

bridge — a bridge service serving this forge proves control and then acts on the forge. manual — no automation; the binding admin declares the namespace and people with forge access carry out the forge-side steps.

Implementation

final PayloadMode mode;