next property

ResponseNext? next
final

Present when the namespace is pending: where the administrator goes to prove control of the forge owner (install the community's forge app, or sign in to the forge and authorise the bridge).

Implementation

final ResponseNext? next;