Response class

What unbinding removed.

Constructors

Response({required NamespaceId namespace, required int rightsRevoked, required int reposDetached, Ext? ext})
const
Response.fromJson(Map<String, dynamic> json)
Read this payload from a decoded JSON object.
factory

Properties

ext → Ext?
final
hashCode → int
The hash code for this object.
no setterinherited
namespace → String
final
reposDetached → int
How many repositories became detached.
final
rightsRevoked → int
How many recorded rights were revoked.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serialize to a JSON-encodable map, omitting absent members.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited