owners property

List<Did> owners
final

The DIDs holding git.repo.own on this repository by an explicit grant. Empty only for an unmanaged repository, and for an orphaned one whose ownership rests with the namespace admins by implication.

Implementation

final List<Did> owners;