resource property
Narrow the answer to this resource and everything inside it. Absent: everything the caller may see.
Implementation
final Resource? resource;
Narrow the answer to this resource and everything inside it. Absent: everything the caller may see.
final Resource? resource;