contextId property
Scope to file the key under. Absence is the most restrictive reading, not a wildcard — see KeyRecord.contextId.
Implementation
final String? contextId;
Scope to file the key under. Absence is the most restrictive reading, not a wildcard — see KeyRecord.contextId.
final String? contextId;