QueueSummary class

Both queues of one account.

Constructors

QueueSummary({required Vid did, AccountType? accountType, required QueueDepth receive, required QueueDepth send})
const
QueueSummary.fromJson(Map<String, dynamic> json)
Read this payload from a decoded JSON object.
factory

Properties

accountType → AccountType?
final
did → String
final
hashCode → int
The hash code for this object.
no setterinherited
receive → QueueDepth
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
send → QueueDepth
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serialize to a JSON-encodable map, omitting absent members.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited