includePeers property
Also return the top N counterparties of each queue by message count. Omitted = no per-peer breakdown.
Implementation
final int? includePeers;
Also return the top N counterparties of each queue by message count. Omitted = no per-peer breakdown.
final int? includePeers;