deliveredUnacked property
Messages in the queue whose state is delivered — handed out but not yet deleted
by the recipient. Absent when the mediator did not measure it.
Implementation
final int? deliveredUnacked;
Messages in the queue whose state is delivered — handed out but not yet deleted
by the recipient. Absent when the mediator did not measure it.
final int? deliveredUnacked;