saturation property
count ÷ limit. Absent when the limit is unlimited. May exceed 1 when a limit was lowered below the current depth.
Implementation
final double? saturation;
count ÷ limit. Absent when the limit is unlimited. May exceed 1 when a limit was lowered below the current depth.
final double? saturation;