candidateModule property

String? candidateModule
final

Optional — when supplied, evaluate as if this Rego source were active (e.g. preview a pending upsert). The candidate is layered into the evaluator at the priority specified by candidatePriority (default 1000) for this call only.

Implementation

final String? candidateModule;