PolicyInputConsumer class

PolicyInputConsumer, generated from its schema.

Constructors

PolicyInputConsumer({required String did, ConsumerKind? kind, String? deviceId, String? lastUserVerificationAt, PolicyInputConsumerNetworkClass? networkClass})
const
PolicyInputConsumer.fromJson(Map<String, dynamic> json)
Read this payload from a decoded JSON object.
factory

Properties

deviceId → String?
final
did → String
final
hashCode → int
The hash code for this object.
no setterinherited
kind → ConsumerKind?
final
lastUserVerificationAt → String?
final
networkClass → PolicyInputConsumerNetworkClass?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serialize to a JSON-encodable map, omitting absent members.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited