DisclosedIntegrity class

DisclosedIntegrity, generated from its schema.

Constructors

DisclosedIntegrity({bool? chainValid, bool? signatureValid, DisclosedIntegrityKeyCustody? keyCustody})
const
DisclosedIntegrity.fromJson(Map<String, dynamic> json)
Read this payload from a decoded JSON object.
factory

Properties

chainValid → bool?
final
hashCode → int
The hash code for this object.
no setterinherited
keyCustody → DisclosedIntegrityKeyCustody?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signatureValid → bool?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serialize to a JSON-encodable map, omitting absent members.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited