ask property
What the holder is asking the maintainer to do. Tagged on type; see
TemplateBootstrapAsk and AdminRotationAsk.
Implementation
final BootstrapAsk ask;
What the holder is asking the maintainer to do. Tagged on type; see
TemplateBootstrapAsk and AdminRotationAsk.
final BootstrapAsk ask;