id property
Opaque maintainer-assigned id for this attachment; used to fetch the blob via a separate mechanism.
Implementation
final String id;
Opaque maintainer-assigned id for this attachment; used to fetch the blob via a separate mechanism.
final String id;