VaultUpsertedEvent class

VaultUpsertedEvent

Constructors

VaultUpsertedEvent({required Object? kind, required int seq, required String occurredAt, required VaultEntry entry})
const
VaultUpsertedEvent.fromJson(Map<String, dynamic> json)
Read this payload from a decoded JSON object.
factory

Properties

entry → VaultEntry
final
hashCode → int
The hash code for this object.
no setterinherited
kind → Object?
final
occurredAt → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seq → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serialize to a JSON-encodable map, omitting absent members.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited