after property
OPTIONAL resulting value at path once the task executes. ABSENT means the value
is removed (a deletion), under the same rule as before.
Implementation
final Object? after;
OPTIONAL resulting value at path once the task executes. ABSENT means the value
is removed (a deletion), under the same rule as before.
final Object? after;