path property
OPTIONAL RFC 6901 JSON Pointer locating the change within the subject resource
(e.g. /service/0).
Implementation
final String? path;
OPTIONAL RFC 6901 JSON Pointer locating the change within the subject resource
(e.g. /service/0).
final String? path;