challenge property

String challenge
final

Per-request nonce (≥128 bits entropy) echoed and signed by the matching task-consent/decision. It is also the salt in payloadDigest, so a party that holds this request can re-derive the digest and a party that does not cannot invert it.

Implementation

final String challenge;