status property
prompted = the request was verified and an approval prompt raised. refused =
the device will not prompt; reason MUST be set.
Implementation
final ResponseStatus status;
prompted = the request was verified and an approval prompt raised. refused =
the device will not prompt; reason MUST be set.
final ResponseStatus status;