retryable property
true if the producer of the original document MAY retry; false if retrying with the same document is not expected to succeed.
Implementation
final bool retryable;
true if the producer of the original document MAY retry; false if retrying with the same document is not expected to succeed.
final bool retryable;