specs/vault/shared/v0_2/session_blob library
Classes
- CookieJarEntry
- CookieJarEntry
- RequestHeader
- RequestHeader
- SessionBlob
- SessionBlob
- StorageEntry
- StorageEntry
Extension Types
- CookieJarEntrySameSite
- CookieJarEntrySameSite is a closed set of string values defined by this specification's schema.
- SessionBlobRefreshHint
-
Tells the Companion when to call back for a refreshed session.
maintainerOnly= don't refresh on your own.on401= call when the third party returns 401.beforeExpiry= pre-emptively refresh shortly beforeexpiresAt.