bindOrigin property
The web origin this session is for. Companions MUST refuse to inject the session into any other origin.
Implementation
final String? bindOrigin;
The web origin this session is for. Companions MUST refuse to inject the session into any other origin.
final String? bindOrigin;