headers property
HTTP request headers the Companion attaches to outbound requests to the bound
origin until expiresAt. Typically holds Authorization: Bearer ….
Implementation
final List<RequestHeader>? headers;
HTTP request headers the Companion attaches to outbound requests to the bound
origin until expiresAt. Typically holds Authorization: Bearer ….
final List<RequestHeader>? headers;