StorageEntry class

StorageEntry

Constructors

StorageEntry({required String key, required String value})
const
StorageEntry.fromJson(Map<String, dynamic> json)
Read this payload from a decoded JSON object.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
key → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serialize to a JSON-encodable map, omitting absent members.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited