lastUserVerificationAt property
Most recent local user-verification on the consumer device (WebAuthn UV, biometric unlock). The maintainer's policy may require this to be within N seconds.
Implementation
final String? lastUserVerificationAt;
Most recent local user-verification on the consumer device (WebAuthn UV, biometric unlock). The maintainer's policy may require this to be within N seconds.
final String? lastUserVerificationAt;