Response class
VTC Admin Bootstrap — response payload
Constructors
Properties
- adminDid → String
-
The admin DID just written to the ACL.
final
- eventId → String
-
event_id of the persisted CommunityInstalled audit envelope (a UUID).
final
- ext → Ext?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Serialize to a JSON-encodable map, omitting absent members.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited