value property
The value the applicant gives. Self-asserted: the applicant's own statement, bound to them by the document proof, and attested by nobody.
Implementation
final Object? value;
The value the applicant gives. Self-asserted: the applicant's own statement, bound to them by the document proof, and attested by nobody.
final Object? value;