WrittenFile class

The file a file upload wrote.

Constructors

WrittenFile({required WebsitePath path, required WebsiteEtag etag, required int sizeBytes})
const
WrittenFile.fromJson(Map<String, dynamic> json)
Read this payload from a decoded JSON object.
factory

Properties

etag → String
final
hashCode → int
The hash code for this object.
no setterinherited
path → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sizeBytes → int
The file's size in bytes.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serialize to a JSON-encodable map, omitting absent members.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited