code property
Present if and only if status is refused: the webvh/sync/update/0.2 error code
the entry would have received on its own (e.g. webvh/sync/update:historyRewrite).
Implementation
final String? code;
Present if and only if status is refused: the webvh/sync/update/0.2 error code
the entry would have received on its own (e.g. webvh/sync/update:historyRewrite).
final String? code;