Response class
WebVH Sync Batch — response payload
Constructors
-
Response({required List<
EntryResult> results, Ext? ext}) -
const
-
Response.fromJson(Map<
String, dynamic> json) -
Read this payload from a decoded JSON object.
factory
Properties
- ext → Ext?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
results
→ List<
EntryResult> -
One result per entry of
updates, in request order.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Serialize to a JSON-encodable map, omitting absent members.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited