didId property
The DID the log establishes. A replica MUST refuse a log that does not establish exactly this DID.
Implementation
final String didId;
The DID the log establishes. A replica MUST refuse a log that does not establish exactly this DID.
final String didId;