Payload class

WebVH Sync Update — payload

Constructors

Payload({required String mnemonic, required String didId, required String logContent, String? witnessContent, required int versionCount, Ext? ext})
const
Payload.fromJson(Map<String, dynamic> json)
Read this payload from a decoded JSON object.
factory

Properties

didId → String
final
ext → Ext?
final
hashCode → int
The hash code for this object.
no setterinherited
logContent → String
final
mnemonic → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
versionCount → int
final
witnessContent → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serialize to a JSON-encodable map, omitting absent members.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited