TransportHandler class abstract interface

A transport binding's plug-in for the framework.

Implementers

Properties

bindingUri → String
A stable identifier for this binding, for logs and audit (9.1, 9.2).
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

deriveParties() → TransportContext
The identities the transport authenticated for the message under consideration.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited