bindingUri property
String
get
bindingUri
A stable identifier for this binding, for logs and audit (9.1, 9.2).
Implementation
String get bindingUri;
A stable identifier for this binding, for logs and audit (9.1, 9.2).
String get bindingUri;