session property
The session the consumer has just created for this subject. session.subject is
principal for a proxied request, issuer otherwise; session.actor is present
and equal to issuer only for a proxied request. Carries sessionKey when the
request bound one.
Implementation
final Session session;