Payload class
List DeviceBindings known to the maintainer, optionally filtered by consumer kind, capability, status, and last-seen time.
Constructors
- Payload({PayloadConsumerKindFilter? consumerKindFilter, PayloadFormFactorFilter? formFactorFilter, PayloadServiceKindFilter? serviceKindFilter, Capability? capabilityFilter, bool? includeDisabled, bool? includeWiped, String? lastSeenSince, int? pageSize, String? cursor, Ext? ext})
-
const
-
Payload.fromJson(Map<
String, dynamic> json) -
Read this payload from a decoded JSON object.
factory
Properties
- capabilityFilter → Capability?
-
final
- consumerKindFilter → PayloadConsumerKindFilter?
-
final
- cursor → String?
-
final
- ext → Ext?
-
final
- formFactorFilter → PayloadFormFactorFilter?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- includeDisabled → bool?
-
When true, include devices with
disabledAtset. Default omits disabled.final - includeWiped → bool?
-
final
- lastSeenSince → String?
-
final
- pageSize → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serviceKindFilter → PayloadServiceKindFilter?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Serialize to a JSON-encodable map, omitting absent members.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited