Response class
The namespace as recorded, and where to go next if it is still pending.
Constructors
- Response({required GitNamespace namespace, ResponseNext? next, Ext? ext})
-
const
-
Response.fromJson(Map<
String, dynamic> json) -
Read this payload from a decoded JSON object.
factory
Properties
- ext → Ext?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- namespace → GitNamespace
-
final
- next → ResponseNext?
-
Present when the namespace is
pending: where the administrator goes to prove control of the forge owner (install the community's forge app, or sign in to the forge and authorise the bridge).final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Serialize to a JSON-encodable map, omitting absent members.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited