forgeId property
The forge's repository id. Absent until the forge has confirmed the repository
exists (a pendingCreate repository, or one adopted in bridge mode before the
first inspection).
Implementation
final ForgeId? forgeId;
The forge's repository id. Absent until the forge has confirmed the repository
exists (a pendingCreate repository, or one adopted in bridge mode before the
first inspection).
final ForgeId? forgeId;