Response class
Policy Evaluate — response payload
Constructors
-
Response({required PolicyDecision decision, List<
String> ? matchedPolicies, List<String> ? trace, Ext? ext}) -
const
-
Response.fromJson(Map<
String, dynamic> json) -
Read this payload from a decoded JSON object.
factory
Properties
- decision → PolicyDecision
-
final
- ext → Ext?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
matchedPolicies
→ List<
String> ? -
Ids (or
candidatefor the dry-run module) of the policies that returned a non-null decision, in evaluation order. The first is the winning policy.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
trace
→ List<
String> ? -
Rego evaluator trace lines when
includeTrace: true. Maintainer-defined format; primarily for human debugging.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Serialize to a JSON-encodable map, omitting absent members.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited